/*
 * Project name:
      Flash MCU test
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080930:
       - initial release;    
 * Description:
     This program demonstrates how to use Flash MCU library.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External, 8.00000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
 * NOTES:
     - None.
 */

const long F_ADDRESS = 0x200;

const unsigned int data_[32] = {                               // constant table
  0x0000,0x0001,0x0002,0x0003,0x0004,0x0005,0x0006,0x0007,
  0x0008,0x0009,0x000A,0x000B,0x000C,0x000D,0x000E,0x000F,
  0x0000,0x0100,0x0200,0x0300,0x0400,0x0500,0x0600,0x0700,
  0x0800,0x0900,0x0A00,0x0B00,0x0C00,0x0D00,0x0E00,0x0F00,
 } absolute F_ADDRESS;

char i;
unsigned int word_;
unsigned int dat_buff[32];

void main() {
  DDRD = 0xFF;                              // set direction to be output
  DDRB = 0xFF;                              // set direction to be output
  word_ = data_[0];                         //  link const table
  
  for (i = 0; i<64 ; i+=2)                  // reading 32 words in loop
    {
      word_  = FLASH_Read_Word(F_ADDRESS + i); //  demonstration of reading single word
      PORTD = word_;                           //  output low byte to PORTD
      PORTB = word_ >> 8;                      //  output higher byte to PORTB
      Delay_ms(200);
    }
  i = 0;
  while ( i < 64 )                                //  reading 64 bytes in loop
    {
      PORTD = FLASH_Read_Byte(F_ADDRESS + i++);   //  demonstration of reading single byte
      PORTB = FLASH_Read_Byte(F_ADDRESS + i++);   //  demonstration of reading single byte
      Delay_ms(200);
    }

  FLASH_Read_Bytes(F_ADDRESS, dat_buff, 64);       //  demonstration of reading 64 bytes
  for (i = 0; i<32 ; i++)
    {
      PORTD = dat_buff[i];                        //  output low byte to PORTD
      PORTB = dat_buff[i] >> 8;                   //  output higher byte to PORTB
      Delay_ms(200);
    }

  FLASH_Read_Words(F_ADDRESS, dat_buff, 32);      //  demonstration of reading 64 words
  for (i = 0; i<32 ; i++)
  {
    PORTD = dat_buff[i];                          //  output low byte to PORTD
    PORTB = dat_buff[i] >> 8;                     //  output higher byte to PORTB
    Delay_ms(200);
  }

}
