/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller
     SW:              mikroC PRO for AVR
 * Notes:
     - Turn on GLCD backlight switch on development board.
*/  

//Declarations------------------------------------------------------------------
const code char truck_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
char GLCD_DataPort at PORTA;
char GLCD_DataPort_Direction at DDRA;

sbit GLCD_CS1 at PORTE.B2;
sbit GLCD_CS2 at PORTE.B3;
sbit GLCD_RS  at PORTE.B4;
sbit GLCD_RW  at PORTE.B5;
sbit GLCD_EN  at PORTE.B6;
sbit GLCD_RST at PORTE.B7;

sbit GLCD_CS1_Direction at DDRE.B2;
sbit GLCD_CS2_Direction at DDRE.B3;
sbit GLCD_RS_Direction  at DDRE.B4;
sbit GLCD_RW_Direction  at DDRE.B5;
sbit GLCD_EN_Direction  at DDRE.B6;
sbit GLCD_RST_Direction at DDRE.B7;
// End Glcd module connections

void delay2S(){                             // 2 seconds delay function
  Delay_ms(2000);
}                 

void main() {                       
  unsigned short ii;                      
  char *someText;

  Glcd_Init();                              // Initialize GLCD
  Glcd_Fill(0x00);                          // Clear GLCD

  while(1) {
    Glcd_Image(truck_bmp);                  // Draw image
    delay2S(); delay2S();

    Glcd_Fill(0x00);                        // Clear GLCD

    Glcd_Box(62,40,124,56,1);               // Draw box
    Glcd_Rectangle(5,5,84,35,1);            // Draw rectangle
    Glcd_Line(0, 0, 127, 63, 1);            // Draw line
    delay2S();

    for(ii = 5; ii < 60; ii+=5 ){           // Draw horizontal and vertical lines
      Delay_ms(250);
      Glcd_V_Line(2, 54, ii, 1);
      Glcd_H_Line(2, 120, ii, 1);
    }

    delay2S();

    Glcd_Fill(0x00);                        // Clear GLCD
    
    Glcd_Set_Font(Character8x7, 8, 7, 32);  // Choose font, see __Lib_GLCDFonts.c in Uses folder
    Glcd_Write_Text("mikroE", 1, 7, 2);     // Write string

    for (ii = 1; ii <= 10; ii++)            // Draw circles
      Glcd_Circle(63,32, 3*ii, 1);
    delay2S();

    Glcd_Box(12,20, 70,57, 2);              // Draw box
    delay2S();
    
    Glcd_Fill(0xFF);                        // Fill GLCD
    
    Glcd_Set_Font(Character8x7, 8, 7, 32);  // Change font
    someText = "8x7 Font";
    Glcd_Write_Text(someText, 5, 0, 2);     // Write string
    delay2S();

    Glcd_Set_Font(System3x5, 3, 5, 32);     // Change font
    someText = "3X5 CAPITALS ONLY";
    Glcd_Write_Text(someText, 60, 2, 2);    // Write string
    delay2S();
    
    Glcd_Set_Font(font5x7, 5, 7, 32);       // Change font
    someText = "5x7 Font";
    Glcd_Write_Text(someText, 5, 4, 2);     // Write string
    delay2S();
    
    Glcd_Set_Font(FontSystem5x7_v2, 5, 7, 32); // Change font
    someText = "5x7 Font (v2)";
    Glcd_Write_Text(someText, 5, 6, 2);     // Write string
    delay2S();
  }
}
