/*
 * Project name:
     Ps2_c_Example (Demonstration on using mikroC's PS/2 keyboard library)
 * Copyright:
     (c) MikroElektronika, 2008
 * Revision History:
     20080930:
       - initial release;
 * Description:
     In this example, key(s) pressed on the PS/2 keyboard are read and transferred
     to PC through serial port connection. Various basic keyboard activities are
     tested: "normal" keys, keys with <Shift> pressed, keys with <Caps Lock>
     pressed, numerical keypad ON/OFF and keys. The result is visible on PC, on
     USART Terminal tool. Alternatively, the results can be seen on an LCD module.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    PS/2 standard 101-keys keyboard
     SW:              mikroC PRO for AVR
 * NOTES:
     - Some keyboards with various multimedia attachments on them (especially the
       cheap ones) tend to "choke" the communication by constantly sending
       requests on various multimedia objects' status (volume, mouse pos. etc.).
       This may slow down the communication pace with the MCU.
     - Diodes off and pull-ups on PORTC may be required.
     - Turn on UART RX and TX UART switches.
 */


unsigned short keydata = 0, special = 0, down = 0;
 
sbit PS2_Data         at PINC.B0;
sbit PS2_Clock_Input  at PINC.B1;
sbit PS2_Clock_Output at PORTC.B1;

sbit PS2_Data_Direction   at DDRC.B0;
sbit PS2_Clock_Direction  at DDRC.B1;

void main() {

  UART1_Init(19200);        // Initialize UART module at 19200 bps
  Ps2_Config();             // Init PS/2 Keyboard
  Delay_ms(100);            // Wait for keyboard to finish
  UART1_Write('R');         // Ready

  do {
    if (Ps2_Key_Read(&keydata, &special, &down)) {
      if (down && (keydata == 16)) {// Backspace
         UART1_Write(0x08);
      }
      else if (down && (keydata == 13)) {// Enter
        UART1_Write('\r');              // send carriage return to usart terminal
        //Usart_Write('\n');             // uncomment this line if usart terminal also expects line feed
                                         // for new line transition
      }
      else if (down && !special && keydata) {
        UART1_Write(keydata);
      }
    }
    Delay_ms(1);            // debounce
  } while (1);
}
