/*
 * Project name:
     PWM (Demonstration of PWM Library)
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080110:
       - initial release;
 * Description:
     This program demonstrates how to correctly enable PWM module, its output pin and
     how to change PWM duty with press of a single button. By pressing (and holding) PORTB pins 0 or 1
     you increment or decrement PWM duty ration of PWM module connected to TIMER/Counter0 (output on
     PORTB pin 3), and by pressing (and holding) PORTC pins 0 or 1
     you increment or decrement PWM duty ration of PWM module connected to TIMER/Counter2 (output on
     PORTB pin 7). This can be easily monitored with osciloscope connected to those pins.
     This example is for ATmega16 MCU, if you are using some other MCU you must check in datasheet
     which output pins does that MCU use and make adjustemnts in the code accordingly.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
 * NOTES:
     - PORTs B, C and D must be in pull-down mode. (board specific)
*/

char current_duty;
char current_duty1;

void main(){

  DDB0_bit = 0;                   // Set PORTB pin 0 as input
  DDB1_bit = 0;                   // Set PORTB pin 1 as input

  DDC0_bit = 0;                   // Set PORTC pin 0 as input
  DDC1_bit = 0;                   // Set PORTC pin 1 as input

  current_duty     = 127;         // initial value for current_duty
  current_duty1    = 127;         // initial value for current_duty

  DDRB.B4 = 1;                    // Set PORTB pin 4 as output pin for the PWM (according to datasheet)
  DDRB.B7 = 1;                    // Set PORTB pin 7 as output pin for the PWM (according to datasheet)
  
  PWM_Init(_PWM_FAST_MODE, _PWM_PRESCALER_8, _PWM_NON_INVERTED, 127);

  PWM1_Init(_PWM1_FAST_MODE, _PWM1_PRESCALER_8, _PWM1_NON_INVERTED, 127);

  do {
    if (PINB.B0) {                              // Detect if PORTB pin 0 is pressed
      Delay_ms(40);                             // Small delay to avoid deboucing effect
      current_duty++;                           // Increment duty ratio
      PWM_Set_Duty(current_duty);               // Set incremented duty
    }
    else
      if (PINB.B1) {                            // Detect if PORTB pin 1 is pressed
        Delay_ms(40);                           // Small delay to avoid deboucing effect
        current_duty--;                         // Decrement duty ratio
        PWM_Set_Duty(current_duty);             // Set decremented duty ratio
      }
      else
        if (PINC.B0) {                          // Detect if PORTC pin 0 is pressed
          Delay_ms(40);                         // Small delay to avoid deboucing effect
          current_duty1++;                      // Increment duty ratio
          PWM1_Set_Duty(current_duty1);         // Set incremented duty
        }
        else
          if (PINC.B1) {                        // Detect if PORTC pin 1 is pressed
            Delay_ms(40);                       // Small delay to avoid deboucing effect
            current_duty1--;                    // Decrement duty ratio
            PWM1_Set_Duty(current_duty1);       // Set decremented duty ratio
          }

  } while(1);                       // Endless loop*/
     
  }
