/*
 * Project name:
     Timer0_Interrupt (Using Timer0 to obtain interrupts)
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This code demonstrates how to use Timer0 and it's interrupt.
     Program toggles LEDs on PORTB.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
 * NOTES:
     - Turn on diodes on PORTB.
*/

const char _THRESHOLD = 244;
char counter;

void Timer0Overflow_ISR() org IVT_ADDR_TIMER0_OVF {

  if (counter >= _THRESHOLD) {
    PORTB = ~PORTB;             // toggle PORTB
    counter = 0;                // reset counter
  }
  else
    counter++;                  // increment counter

}

void main() {

  DDRB   =  0xFF;               // set PORTB as output
  PORTB  =  0;                  // clear PORTB

  SREG_I_bit = 1;               // Interrupt enable
  TOIE0_bit  = 1;               // Timer0 overflow interrupt enable
  TCCR0 = 5;                    // Start timer with 128 prescaler

  while (1)                     // Endless loop, port is changed inside Interrupt Service Routine (ISR)
    ;
}
