/*
 * Project name:
     Timer1_Interrupt (Using Timer1 to obtain interrupts)
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This code demonstrates how to use Timer1 and it's interrupt.
     Program toggles LEDs on PORTB.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
 * NOTES:
     - Turn on diodes on PORTB.
*/

const char _THRESHOLD = 15;
char counter;

void Timer1Overflow_ISR() org IVT_ADDR_TIMER1_OVF {

  if (counter >= _THRESHOLD) {
    PORTB = ~PORTB;             // toggle PORTB
    counter = 0;                // reset counter
  }
  else
    counter++;                  // increment counter

}

void main() {

  DDRB   = 0xFF;                // set PORTB as output
  PORTB  = 0;                   // clear PORTB

  SREG_I_bit = 1;               // Interrupt enable
  TOIE1_bit  = 1;               // Timer1 overflow interrupt enable
  TCCR1B = 2;                   // Start timer with 8 prescaler

  while (1)                     // Endless loop, port is changed inside Interrupt Service Routine (ISR)
    ;
}
