/*
 * Project name:
     Timer2_Interrupt (Using Timer2 to obtain interrupts)
 * Copyright:
     (c) Mikroelektronika, 2008.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This code demonstrates how to use Timer2 and it's interrupt.
     Program toggles LEDs on PORTB.
 * Test configuration:
     MCU:             ATmega128
     Dev.Board:       BigAVR2
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
 * NOTES:
     - Turn on diodes on PORTB.
*/

const char _THRESHOLD = 30;
char counter;

void Timer2Overflow_ISR() org IVT_ADDR_TIMER2_OVF {
  if (counter >= _THRESHOLD) {
    PORTB = ~PORTB;             // toggle PORTB
    counter = 0;                // reset counter
  }
  else
    counter++;                  // increment counter
}

void main() {

  DDRB   = 0xFF;                // set PORTB as output
  PORTB  = 0;                   // clear PORTB

  SREG_I_bit = 1;               // Interrupt enable
  TOIE2_bit  = 1;               // Timer2 overflow interrupt enable
  TCCR2  = 5;                   // Start timer with 1024 prescaler

  while (1)                     // Endless loop, port is changed inside Interrupt Service Routine (ISR)
    ;
}
